@@ -171,7 +171,7 @@ class RootController(TGController):
         article.title = kw['title']
         article.description = kw['description']
         article.content = kw['content']
-        article.publish_date = datetime.strptime(kw['publish_date'], '%Y-%m-%d %H:%M')
+        article.publish_date = kw['publish_date']
         article.update_date = datetime.now()
         app_model.Tagging.set_tags(article, kw['tags'])
 
